#
# spec file for package orc
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2010 Dominique Leuenberger, Amsterdam, Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           orc
Summary:        The Oil Runtime Compiler
Version:        0.4.16
Release:        28.1
License:        BSD and Motorola License (please mark changes)
Group:          Productivity/Multimedia/Other
Url:            http://code.entropywave.com/projects/orc/
Source:         http://code.entropywave.com/download/orc/%{name}-%{version}.tar.gz
Source99:       baselibs.conf
BuildRequires:  gtk-doc
BuildRequires:  pkg-config
Provides:       %{name}-devel = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Orc is a library and set of tools for compiling and executing very simple
programs that operate on arrays of data.  The “language” is a generic
assembly language that represents many of the features available in SIMD
architectures, including saturated addition and subtraction, and many
arithmetic operations.

%package -n liborc-0_4-0
License:        BSD and Motorola License (please mark changes)
Summary:        The Oil Runtime Compiler Library
Group:          System/Libraries

%description -n liborc-0_4-0
Orc is a library and set of tools for compiling and executing very simple
programs that operate on arrays of data.  The “language” is a generic
assembly language that represents many of the features available in SIMD
architectures, including saturated addition and subtraction, and many
arithmetic operations.

%package doc
License:        BSD and Motorola License (please mark changes)
Summary:        The Oil Runtime Compiler Library - Documentation
Group:          Documentation/HTML

%description doc
Orc is a library and set of tools for compiling and executing very simple
programs that operate on arrays of data.  The “language” is a generic
assembly language that represents many of the features available in SIMD
architectures, including saturated addition and subtraction, and many
arithmetic operations.

%prep
%setup -q

%build
%configure \
    --disable-static \
    --enable-gtk-doc
%{__make} %{?jobs:-j%jobs}

%install
%makeinstall
# These are some examples that seem not to make sense to be distributed
rm -rf %{buildroot}%{_libdir}/orc
# Remove libtool archives
find %{buildroot}%{_libdir} -name '*.la' -delete -print

%check
make check

%clean
rm -rf %{buildroot}

%post -n liborc-0_4-0 -p /sbin/ldconfig

%postun -n liborc-0_4-0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/orc-bugreport
%{_bindir}/orcc
%{_includedir}/orc-0.4/
%{_libdir}/*.so
%{_libdir}/pkgconfig/orc-0.4.pc
%{_datadir}/aclocal/orc.m4

%files doc
%defattr(-,root,root)
%{_datadir}/gtk-doc/html/orc/

%files -n liborc-0_4-0
%defattr(-,root,root)
%{_libdir}/liborc*-0.4.so.*

%changelog
* Tue Oct  4 2011 vuntz@opensuse.org
- Update to version 0.4.16:
  + orc_init() tried to take the same mutex as generated C code
    that calls (indirectly) orc_init().
  + sse: Fixes for 64 bit pointers with any of the upper 32 bits
    set.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 0.4.15:
  + Protect global resources with mutexes.
  + Restore c64x-c backend (untested).
  + Convert MMX and SSE backends to a new instruction scheduler.
  + Add alignment and size hints to parser.
* Mon Jul  4 2011 vuntz@opensuse.org
- Update to version 0.4.14:
  + Various fixes for SSE, MMX and Altivec
  + Fix endianness issues
* Wed Apr 27 2011 chris@computersalat.de
- Update to version 0.4.13:
  + Fixes two serious code generation bugs in 0.4.12 on SSE and
    Altivec.
  + Add some compatibility code to mitigate the previous automatic
    inclusion of stdint.h
- Changes from version 0.4.12:
  + Fix gcc-4.6 warnings in generated code
  + Codegen fixes for Altivec. Passes regression tests again.
  + More error checking for code allocation.
  + NEON: floating point improvements
  + Removed stdint.h from API. This could theoretically cause
    breakage if you depended on orc to include stdint.h.
  + Addition of the OrcCode structure, which keeps track of
    compiled code. This now allows applications to free unused
    code.
  + x86 code generation was completely refactored to add an
    intermediate stage, which will later be used for instruction
    reordering.
* Wed Dec  8 2010 cristian.rodriguez@opensuse.org
- Run make check
* Mon Oct 18 2010 vuntz@opensuse.org
- Update to version 0.4.11:
  + Fixes for CPUs that don't have backends
  + Fix loading of double parameters
  + mmx: Fix 64-bit parameter loading
  + sse/mmx: Fix x2/x4 with certain opcodes
* Sat Oct  9 2010 vuntz@opensuse.org
- Update to version 0.4.10:
  + Added several simple 64-bit opcodes
  + Improved debugging by adding ORC_CODE=emulate
  + Allocation of mmap’d areas for code now has several fallback
    methods, in order to placate various SELinux configurations.
  + Various speed improvements in SSE backend
  + Add SSE implementations of ldreslinl and ldresnearl.
  + Update Mersenne Twister example
* Mon Sep  6 2010 vuntz@opensuse.org
- Update to version 0.4.9:
  + Added handling for 64-bit constants
  + Fix building and use of static library
  + Fix register allocation on Win64 (still partly broken, however)
  + Quiet some non-errors printed by orcc in 0.4.8.
  + Fix implementation of several opcodes.
  + Until this release, the shared libraries all had the same
    versioning information. This should be fixed going forward.
* Mon Aug 30 2010 vuntz@opensuse.org
- Update to version 0.4.8:
  + Fix Windows and OS/X builds
  + Improve behavior in failure cases
  + Major improvements for Altivec backend
  + Significant documentation additions
  + Memory for executable code storage is now handled in a much
    more controlled manner, and it's now possible to reclaim this
    memory after it's no longer needed.
  + A few more 64-bit opcodes have been added, mostly related to
    arithmetic on floating point values.
  + The orcc tool now handles 64-bit and floating point parameters
    and constants.
- Add baselibs.conf.
* Thu Aug 26 2010 vuntz@opensuse.org
- Update to version 0.4.7:
  + Lots of specialized new opcodes and opcode prefixes.
  + Important fixes for ARM backend
  + Improved emulation of programs (much faster)
  + Implemented fallback rules for almost all opcodes for SSE and
    NEON backends
  + Performance improvements for SSE and NEON backends.
  + Many fixes to make larger programs compile properly.
  + 64-bit data types are now fully implemented, although there are
    few operations on them.
  + Loads and stores are now handled by separate opcodes (loadb,
    storeb, etc). For compatibility, these are automatically
    included where necessary. This allowed new specialized loading
    opcodes, for example, resampling a source array for use in
    scaling images.
  + Opcodes may now be prefixed by "x2" or "x4", indicating that a
    operation should be done on 2 or 4 parts of a proportionally
    larger value. For example, "x4 addusb" performs 4 saturated
    unsigned additions on each of the four bytes of 32-bit
    quantities. This is useful in pixel operations.
  + The MMX backend is now (semi-) automatically generated from the
    SSE backend.
  + The orcc tool has a new option "-inline", which creates inline
    versions of the Orc stub functions. The orcc tool also
    recognizes a new directive ‘.init’, which instructs the
    compiler to generate an initialization function, which when
    called at application init time, compiles all the generated
    functions. This allows the generated stub functions to avoid
    checking if the function has already been compiled. The use of
    these two features can dramatically decrease the cost of
    calling Orc functions.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 0.4.6:
  + Various fixes to make Orc more portable
  + Major performance improvements to NEON backend
  + Minor performance improvements to SSE backend
  + Major improvements to ARM backend, now passes regression tests.
  + The defaults for floating point operations have been changed
    somewhat: NANs are handled more like the IEEE 754 standard, and
    denormals in operations are treated as zeros. The NAN changes
    causes certain SSE operations to be slightly slower, but produce
    less surprising results. Treating denormals as zero has effects
    ranging from “slightly faster” to “now possible”.
  + New tool: orc-bugreport. Mainly this is to provide a limited
    testing tool in the field, especially for embedded targets
    which would not have access to the testsuite that is not
    installed.
  + The environment variable ORC_CODE can now be used to adjust
    some code generation. See orc-bugreport -help for details.
  + orcc has a new option to generate code that is compatible with
    older versions of Orc.
  + New NEON detection relies on Linux 2.6.29 or later.
- Changes from version 0.4.5:
  + Many small improvements related to converting GStreamer from
    liboil to Orc.
  + The major addition in this release is the mainstreaming of
    the NEON backend, made possible by Nokia.
  + There is a new experimental option to ./configure,
  - -enable-backend, which allows you to choose a single code
    generation backend to include in the library. This is mostly
    useful for embedded systems, and is not recommended in general.
- Do not call autogen.sh and remove workaround for doc generation.
* Tue May 25 2010 chris@computersalat.de
- update to version 0.4.4
  o remove obsolete orc-asneeded.patch
* Wed Mar 17 2010 dimstar@opensuse.org
- Initial package of orc 0.4.3
